# [Django Black Dashboard](https://app-generator.dev/docs/products/django-libs/theme-black-dashboard.html)

Modern template for **[Django Admin](https://app-generator.dev/docs/products/django-libs/theme-black-dashboard.html)**, Auth Pages (registration included) crafted on top of **Black Dashboard**, an open-source **Bootstrap** design.

- [Django Admin Black](https://app-generator.dev/docs/products/django-libs/theme-black-dashboard.html) - Documentation & Support Links
- [Django Black Dashboard](https://app-generator.dev/product/black-dashboard/django/) - The product that uses the library
- [Getting Started with Django](https://app-generator.dev/docs/technologies/django/index.html) - Learn how to code **Django** Projects

<br />

## **Features**

- Design: **[Black Dashboard](https://app-generator.dev/docs/templates/bootstrap/black-dashboard.html)** (Bootstrap)
- **Sections Covered**: 
  - `Admin Section`, reserved for `superusers`
  - `All pages` managed by `Django.contrib.AUTH`
  - `Registration` page
  - `Misc pages`: colors, icons, typography, blank-page 
  
<br />

![Django Black Dashboard - Modern template for Django Admin Section crafted on top of a modern Bootstrap Design.](https://user-images.githubusercontent.com/51070104/196730732-dda1794b-93ce-48cb-bc5c-182411495512.png)

<br />

---
**[Django Black Dashboard](https://app-generator.dev/docs/products/django-libs/theme-black-dashboard.html)** - Modern Django Admin Interface provided by **[App-Generator](https://app-generator.dev)**
